@@ -5,14 +5,15 @@ rm -f units/*/*
 
 # Clean up components output directories
 rm -rf components/chsdet/lib/*
-rm -rf components/CmdLine/lib/*
 rm -rf components/dcpcrypt/lib/*
 rm -rf components/doublecmd/lib/*
 rm -rf components/gifanim/lib/*
+rm -rf components/Image32/lib/*
 rm -rf components/KASToolBar/lib/*
 rm -rf components/multithreadprocs/lib/*
 rm -rf components/viewer/lib/*
 rm -rf components/synunihighlighter/lib/*
+rm -rf components/virtualterminal/lib/*
 
 # Clean up all temporary files
 find . -iname '*.compiled' -delete
@@ -27,6 +28,7 @@ rm -f src/doublecmd.res doublecmd
 rm -f tools/extractdwrflnfo
 rm -f plugins/wcx/unrar/lib/rarconfdlg.lfm
 rm -f plugins/wcx/zip/lib/ZipConfDlg.lfm
+rm -f plugins/wcx/zip/lib/ZipLng.rsj
 rm -f plugins/wcx/zip/lib/abresstring.rs?
 rm -f plugins/wfx/ftp/lib/FtpConfDlg.lfm
 rm -f plugins/wfx/samba/lib/smbauthdlg.lfm
