@@ -25,14 +25,15 @@ fi
 basedir=$(pwd)
 cd components
 $lazbuild chsdet/chsdet.lpk $DC_ARCH
-$lazbuild CmdLine/cmdbox.lpk $DC_ARCH
 $lazbuild multithreadprocs/multithreadprocslaz.lpk $DC_ARCH
 $lazbuild dcpcrypt/dcpcrypt.lpk $DC_ARCH
 $lazbuild doublecmd/doublecmd_common.lpk $DC_ARCH
+$lazbuild Image32/Image32.lpk $DC_ARCH
 $lazbuild KASToolBar/kascomp.lpk $DC_ARCH
 $lazbuild viewer/viewerpackage.lpk $DC_ARCH
 $lazbuild gifanim/pkg_gifanim.lpk $DC_ARCH
 $lazbuild synunihighlighter/synuni.lpk $DC_ARCH
+$lazbuild virtualterminal/virtualterminal.lpk $DC_ARCH
 cd $basedir
 
 # Remove temporary file
