@@ -14,6 +14,7 @@ mkdir -p $DC_INSTALL_DIR/plugins
 
 # WCX plugins directories
 mkdir -p $DC_INSTALL_DIR/plugins/wcx
+mkdir -p $DC_INSTALL_DIR/plugins/wcx/base64
 mkdir -p $DC_INSTALL_DIR/plugins/wcx/cpio
 mkdir -p $DC_INSTALL_DIR/plugins/wcx/deb
 mkdir -p $DC_INSTALL_DIR/plugins/wcx/rpm
@@ -28,19 +29,21 @@ mkdir -p $DC_INSTALL_DIR/plugins/wdx/audioinfo
 # WFX plugins directories
 mkdir -p $DC_INSTALL_DIR/plugins/wfx
 mkdir -p $DC_INSTALL_DIR/plugins/wfx/ftp
+# WLX plugins directories
+mkdir -p $DC_INSTALL_DIR/plugins/wlx
+mkdir -p $DC_INSTALL_DIR/plugins/wlx/MacPreview
 
 # Copy files
 cp -r doublecmd.app/*              $DC_APP_DIR/
 cp -a doublecmd                    $DC_INSTALL_DIR/
 cp -a doublecmd.help               $DC_INSTALL_DIR/
 cp -a doublecmd.zdli               $DC_INSTALL_DIR/
-cp -a pixmaps.txt                  $DC_INSTALL_DIR/
-cp -a multiarc.ini                 $DC_INSTALL_DIR/
 cp -a pinyin.tbl                   $DC_INSTALL_DIR/
 
 # Copy plugins
 
 # WCX
+install -m 644 plugins/wcx/base64/base64.wcx        $DC_INSTALL_DIR/plugins/wcx/base64/
 install -m 644 plugins/wcx/cpio/cpio.wcx            $DC_INSTALL_DIR/plugins/wcx/cpio/
 install -m 644 plugins/wcx/deb/deb.wcx              $DC_INSTALL_DIR/plugins/wcx/deb/
 install -m 644 plugins/wcx/rpm/rpm.wcx              $DC_INSTALL_DIR/plugins/wcx/rpm/
@@ -58,6 +61,8 @@ install -m 644 plugins/wdx/audioinfo/audioinfo.lng  $DC_INSTALL_DIR/plugins/wdx/
 cp -r plugins/wfx/ftp/language                      $DC_INSTALL_DIR/plugins/wfx/ftp
 install -m 644 plugins/wfx/ftp/ftp.wfx              $DC_INSTALL_DIR/plugins/wfx/ftp/
 install -m 644 plugins/wfx/ftp/src/ftp.ico          $DC_INSTALL_DIR/plugins/wfx/ftp/
+# WLX
+install -m 644 plugins/wlx/MacPreview/MacPreview.wlx $DC_INSTALL_DIR/plugins/wlx/MacPreview/
 
 # Copy documentation
 mkdir -p $DC_INSTALL_DIR/doc
@@ -68,6 +73,7 @@ mkdir -p $DC_INSTALL_DIR/scripts
 cp -a scripts/terminal.sh $DC_INSTALL_DIR/scripts/
 
 # Copy directories
+cp -r default      $DC_INSTALL_DIR/
 cp -r language     $DC_INSTALL_DIR/
 cp -r pixmaps      $DC_INSTALL_DIR/
 cp -r highlighters $DC_INSTALL_DIR/
